Documentation — Django Grappelli 2.14.3 documentation

# Documentation

A jazzy skin for the Django admin interface.

This documentation covers version 2.14.3 of Grappelli. Grappelli is a grid-based alternative/extension to the Django administration interface.

Note

Grappelli 2.14.3 requires Django 3.1. More on Versions and Compatibility.

## Installation & Setup

- Quick start guide
  - Installation
  - Setup
  - Testing
- Customization
  - Available Settings
  - Collapsibles
  - Inline Sortables
  - Rearrange Inlines
  - Related Lookups
  - Autocomplete Lookups
  - Using TinyMCE
  - Changelist Templates
  - Changelist Filters
  - Switch User
  - Clean input types

## Dashboard

- Dashboard Setup
  - Custom dashboard
  - Custom dashboards for multiple sites
- Dashboard API
  - The Dashboard class
  - The DashboardModule class
  - The Group class
  - The LinkList class
  - The AppList class
  - The ModelList class
  - The RecentActions class
  - The Feed class

## Internals

- Internals
  - Templates
  - Javascripts

## Help

- Help
  - FAQ
  - Best Practice
  - Third Party Applications
  - Troubleshooting
  - Django Issues
  - Grappelli 2.14.x Release Notes
- Contributing
- Changelog

## Code

https://github.com/sehmaschine/django-grappelli

## Website

http://www.grappelliproject.com

## Discussion

Use the Grappelli Google Group to ask questions or discuss features.

## Versions and Compatibility

Grappelli is always developed against the latest stable Django release and is NOT tested with Django’s master branch.

- Grappelli 2.14.3 (Nov 23rd, 2020): Compatible with Django 3.1

- Grappelli 2.13.4 (February 10th, 2020): Compatible with Django 2.2 (LTS)

- Grappelli 2.10.4 (November 1st, 2018): Compatible with Django 1.11 (LTS)

Current development branches:

- Grappelli 2.14.4 (Development version for Django 3.1, see branch Stable/2.14.x)

- Grappelli 2.13.5 (Development version for Django 2.2, see branch Stable/2.13.x)

- Grappelli 2.10.5 (Development version for Django 1.11, see branch Stable/2.10.x)

Older versions are available at GitHub, but are not supported anymore.